@@ -410,7 +410,7 @@ class Montezuma(AtariEnvironment):
         self,
         name="PlanMontezuma-v0",
         frameskip: int = 1,
-        episodic_live: bool = False,
+        episodic_life: bool = False,
         autoreset: bool = True,
         delay_setup: bool = False,
         remove_time_limit: bool = True,
@@ -432,7 +432,7 @@ class Montezuma(AtariEnvironment):
             name="MontezumaRevengeDeterministic-v4",
             frameskip=frameskip,
             autoreset=autoreset,
-            episodic_live=episodic_live,
+            episodic_life=episodic_life,
             clone_seeds=False,
             delay_setup=delay_setup,
             remove_time_limit=remove_time_limit,
