@@ -6,6 +6,7 @@ from plangym.dm_control import DMControlEnv
 from plangym.environment_names import ATARI, BOX_2D, CLASSIC_CONTROL, DM_CONTROL, RETRO
 from plangym.minimal import MinimalPacman, MinimalPong
 from plangym.montezuma import Montezuma
+from plangym.nes import MarioEnvironment
 from plangym.parallel import ParallelEnvironment
 from plangym.ray import RayEnv
 from plangym.retro import RetroEnvironment
@@ -31,6 +32,8 @@ def get_planenv_class(name, domain_name, state):
         return AtariEnvironment
     elif domain_name is not None or any(x[0] in name for x in DM_CONTROL):
         return DMControlEnv
+    elif "SuperMarioBros" in name:
+        return MarioEnvironment
     raise ValueError(f"Environment {name} is not supported.")
 
 
